Skip continu runing testcase if SSTATE_DIR or DL_DIR no set in page
Signed-off-by: Alassane Yattara <[email protected]>
---
 lib/toaster/tests/functional/test_project_config.py | 9 +++++----
 1 file changed, 5 insertions(+), 4 deletions(-)

diff --git a/lib/toaster/tests/functional/test_project_config.py 
b/lib/toaster/tests/functional/test_project_config.py
index 2d162d81..c70936e1 100644
--- a/lib/toaster/tests/functional/test_project_config.py
+++ b/lib/toaster/tests/functional/test_project_config.py
@@ -162,8 +162,9 @@ class TestProjectConfig(SeleniumFunctionalTestCase):
         try:
             change_dl_dir_btn = self.wait_until_visible('#change-dl_dir-icon', 
poll=2)
         except TimeoutException:
-            # If download dir is not displayed, test is skipped
-            return True
+            # skip test if becase variable DL_DIR is not set/visible in page
+            self.skipTest('DL_DIR is not set/visible in the page 
project/BitBake variables')
+
         change_dl_dir_btn = self.wait_until_visible('#change-dl_dir-icon', 
poll=2)
         change_dl_dir_btn.click()
 
@@ -220,8 +221,8 @@ class TestProjectConfig(SeleniumFunctionalTestCase):
             self.wait_until_visible('#change-sstate_dir-icon', poll=2)
             self.click('#change-sstate_dir-icon')
         except TimeoutException:
-            # If sstate_dir is not displayed, test is skipped
-            return True
+            # skip test if becase variable SSTATE_DIR is not set/visible in 
page
+            self.skipTest('SSTATE_DIR is not set/visible in the page 
project/BitBake variables')
 
         # path doesn't start with / or ${...}
         input_field = self.wait_until_visible('#new-sstate_dir', poll=2)
-- 
2.34.1

-=-=-=-=-=-=-=-=-=-=-=-
Links: You receive all messages sent to this group.
View/Reply Online (#6106): https://lists.yoctoproject.org/g/toaster/message/6106
Mute This Topic: https://lists.yoctoproject.org/mt/103179912/21656
Group Owner: [email protected]
Unsubscribe: https://lists.yoctoproject.org/g/toaster/unsub 
[[email protected]]
-=-=-=-=-=-=-=-=-=-=-=-

Reply via email to